# SPDX-FileCopyrightText: 2023-present Anders Steen <asteennilsen@gmail.com
#
# SPDX-License-Identifier: MIT
import sys

if __name__ == '__main__':
    from zshgpt.cli import zshgpt

    sys.exit(zshgpt())
